Type: Package
Package: effectsize
Title: Indices of Effect Size
Version: 0.8.0
Authors@R: 
    c(person(given = "Mattan S.",
             family = "Ben-Shachar",
             role = c("aut", "cre"),
             email = "mattansb@msbstats.info",
             comment = c(ORCID = "0000-0002-4287-4801", Twitter = "@mattansb")),
      person(given = "Dominique",
             family = "Makowski",
             role = "aut",
             email = "dom.makowski@gmail.com",
             comment = c(ORCID = "0000-0001-5375-9967", Twitter = "@Dom_Makowski")),
      person(given = "Daniel",
             family = "Lüdecke",
             role = "aut",
             email = "d.luedecke@uke.de",
             comment = c(ORCID = "0000-0002-8895-3206", Twitter = "@strengejacke")),
      person(given = "Indrajeet",
             family = "Patil",
             role = "aut",
             email = "patilindrajeet.science@gmail.com",
             comment = c(ORCID = "0000-0003-1995-6531", Twitter = "@patilindrajeets")),
      person(given = "Brenton M.",
             family = "Wiernik",
             role = "aut",
             email = "brenton@wiernik.org",
             comment = c(ORCID = "0000-0001-9560-6336", Twitter = "@bmwiernik")),
      person(given = "Ken",
             family = "Kelley",
             role = "ctb"),
      person(given = "David",
             family = "Stanley",
             role = "ctb"),
      person(given = "Jessica",
             family = "Burnett",
             role = "rev",
             email = "jburnett@usgs.gov",
             comment = c(ORCID = "0000-0002-0896-5099")),
      person(given = "Johannes",
             family = "Karreth",
             role = "rev",
             email = "jkarreth@ursinus.edu",
             comment = c(ORCID = "0000-0003-4586-7153")))
Maintainer: Mattan S. Ben-Shachar <mattansb@msbstats.info>
Description: Provide utilities to work with indices of effect size for a wide 
    variety of models and hypothesis tests (see list of supported models using 
    the function 'insight::supported_models()'), allowing computation of and 
    conversion between indices such as Cohen's d, r, odds, etc.
    References: Ben-Shachar et al. (2020) <doi:10.21105/joss.02815>.
License: GPL-3
URL: https://easystats.github.io/effectsize/
BugReports: https://github.com/easystats/effectsize/issues/
Depends: R (>= 3.6)
Imports: bayestestR (>= 0.13.0), insight (>= 0.18.4), parameters (>=
        0.19.0), performance (>= 0.10.0), datawizard (>= 0.6.2), stats,
        utils
Suggests: correlation (>= 0.8.2), see (>= 0.7.3), afex, BayesFactor,
        boot, brms, car, emmeans, knitr, lavaan, lme4, lmerTest, MASS,
        mgcv, parsnip, rmarkdown, rms, rstanarm, rstantools, testthat
        (>= 3.1.0)
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.2.1.9000
Config/testthat/edition: 3
Config/testthat/parallel: true
Config/Needs/website: rstudio/bslib, r-lib/pkgdown,
        easystats/easystatstemplate
NeedsCompilation: no
Packaged: 2022-10-09 13:28:04 UTC; user
Author: Mattan S. Ben-Shachar [aut, cre]
    (<https://orcid.org/0000-0002-4287-4801>, @mattansb),
  Dominique Makowski [aut] (<https://orcid.org/0000-0001-5375-9967>,
    @Dom_Makowski),
  Daniel Lüdecke [aut] (<https://orcid.org/0000-0002-8895-3206>,
    @strengejacke),
  Indrajeet Patil [aut] (<https://orcid.org/0000-0003-1995-6531>,
    @patilindrajeets),
  Brenton M. Wiernik [aut] (<https://orcid.org/0000-0001-9560-6336>,
    @bmwiernik),
  Ken Kelley [ctb],
  David Stanley [ctb],
  Jessica Burnett [rev] (<https://orcid.org/0000-0002-0896-5099>),
  Johannes Karreth [rev] (<https://orcid.org/0000-0003-4586-7153>)
Repository: CRAN
Date/Publication: 2022-10-09 19:30:02 UTC
