# Generated by roxygen2: do not edit by hand

S3method(.anova_es,model_fit)
S3method(d_to_cles,effectsize_difference)
S3method(d_to_cles,numeric)
S3method(effectsize,BFBayesFactor)
S3method(effectsize,afex_aov)
S3method(effectsize,anova)
S3method(effectsize,aov)
S3method(effectsize,aovlist)
S3method(effectsize,default)
S3method(effectsize,easycorrelation)
S3method(effectsize,htest)
S3method(equivalence_test,effectsize_table)
S3method(eta_squared_posterior,brmsfit)
S3method(eta_squared_posterior,stanreg)
S3method(format,effectsize_table)
S3method(format,equivalence_test_effectsize)
S3method(interpret,effectsize_table)
S3method(interpret,lavaan)
S3method(interpret,numeric)
S3method(interpret,performance_lavaan)
S3method(odds_to_probs,data.frame)
S3method(odds_to_probs,numeric)
S3method(oddsratio_to_riskratio,default)
S3method(oddsratio_to_riskratio,numeric)
S3method(plot,effectsize_table)
S3method(plot,equivalence_test_effectsize)
S3method(print,effectsize_anova)
S3method(print,effectsize_difference)
S3method(print,effectsize_interpret)
S3method(print,effectsize_std_params)
S3method(print,effectsize_table)
S3method(print,equivalence_test_effectsize)
S3method(print,rules)
S3method(probs_to_odds,data.frame)
S3method(probs_to_odds,numeric)
S3method(rb_to_cles,effectsize_difference)
S3method(rb_to_cles,numeric)
S3method(standardize,Surv)
S3method(standardize,bcplm)
S3method(standardize,clm2)
S3method(standardize,default)
S3method(standardize,mediate)
S3method(standardize,wbgee)
S3method(standardize,wbm)
S3method(standardize_info,default)
S3method(standardize_parameters,bootstrap_model)
S3method(standardize_parameters,bootstrap_parameters)
S3method(standardize_parameters,default)
S3method(standardize_parameters,mediate)
S3method(standardize_parameters,model_fit)
S3method(standardize_parameters,parameters_model)
export(.es_aov_simple)
export(.es_aov_strata)
export(.es_aov_table)
export(F_to_d)
export(F_to_epsilon2)
export(F_to_eta2)
export(F_to_eta2_adj)
export(F_to_f)
export(F_to_f2)
export(F_to_omega2)
export(F_to_r)
export(adjust)
export(change_scale)
export(chisq_to_cohens_w)
export(chisq_to_cramers_v)
export(chisq_to_pearsons_c)
export(chisq_to_phi)
export(cles)
export(cliffs_delta)
export(cohens_d)
export(cohens_f)
export(cohens_f_squared)
export(cohens_g)
export(cohens_h)
export(cohens_u3)
export(cohens_w)
export(common_language)
export(convert_d_to_common_language)
export(convert_d_to_oddsratio)
export(convert_d_to_r)
export(convert_logoddsratio_to_d)
export(convert_logoddsratio_to_r)
export(convert_odds_to_probs)
export(convert_oddsratio_to_d)
export(convert_oddsratio_to_r)
export(convert_probs_to_odds)
export(convert_r_to_d)
export(convert_r_to_oddsratio)
export(convert_rb_to_common_language)
export(cramers_v)
export(d_to_cles)
export(d_to_common_language)
export(d_to_oddsratio)
export(d_to_r)
export(effectsize)
export(epsilon_squared)
export(equivalence_test)
export(eta2_to_f)
export(eta2_to_f2)
export(eta_squared)
export(eta_squared_posterior)
export(f2_to_eta2)
export(f_to_eta2)
export(format_standardize)
export(get_effectsize_label)
export(get_effectsize_name)
export(glass_delta)
export(hedges_g)
export(interpret)
export(interpret_agfi)
export(interpret_bf)
export(interpret_cfi)
export(interpret_cohens_d)
export(interpret_cohens_g)
export(interpret_cramers_v)
export(interpret_d)
export(interpret_delta)
export(interpret_direction)
export(interpret_epsilon_squared)
export(interpret_ess)
export(interpret_eta_squared)
export(interpret_g)
export(interpret_gfi)
export(interpret_glass_delta)
export(interpret_hedges_g)
export(interpret_icc)
export(interpret_ifi)
export(interpret_kendalls_w)
export(interpret_nfi)
export(interpret_nnfi)
export(interpret_oddsratio)
export(interpret_omega_squared)
export(interpret_p)
export(interpret_parameters)
export(interpret_pd)
export(interpret_phi)
export(interpret_pnfi)
export(interpret_r)
export(interpret_r2)
export(interpret_rank_biserial)
export(interpret_rfi)
export(interpret_rhat)
export(interpret_rmsea)
export(interpret_rope)
export(interpret_srmr)
export(interpret_vif)
export(is.rules)
export(is_effectsize_name)
export(kendalls_w)
export(logoddsratio_to_d)
export(logoddsratio_to_r)
export(mad_pooled)
export(normalize)
export(odds_to_probs)
export(oddsratio)
export(oddsratio_to_d)
export(oddsratio_to_r)
export(oddsratio_to_riskratio)
export(omega_squared)
export(p_overlap)
export(p_superiority)
export(pearsons_c)
export(phi)
export(phi_to_chisq)
export(probs_to_odds)
export(r_to_d)
export(r_to_oddsratio)
export(rank_biserial)
export(rank_epsilon_squared)
export(ranktransform)
export(rb_to_cles)
export(rb_to_common_language)
export(riskratio)
export(riskratio_to_oddsratio)
export(rules)
export(sd_pooled)
export(standardize)
export(standardize_info)
export(standardize_parameters)
export(standardize_posteriors)
export(t_to_d)
export(t_to_epsilon2)
export(t_to_eta2)
export(t_to_eta2_adj)
export(t_to_f)
export(t_to_f2)
export(t_to_omega2)
export(t_to_r)
export(unstandardize)
export(z_to_d)
export(z_to_r)
importFrom(bayestestR,describe_posterior)
importFrom(bayestestR,equivalence_test)
importFrom(datawizard,adjust)
importFrom(datawizard,change_scale)
importFrom(datawizard,demean)
importFrom(datawizard,normalize)
importFrom(datawizard,ranktransform)
importFrom(datawizard,standardize)
importFrom(datawizard,unstandardize)
importFrom(insight,check_if_installed)
importFrom(insight,clean_names)
importFrom(insight,find_formula)
importFrom(insight,find_predictors)
importFrom(insight,find_random)
importFrom(insight,find_response)
importFrom(insight,find_terms)
importFrom(insight,find_weights)
importFrom(insight,format_value)
importFrom(insight,get_data)
importFrom(insight,get_parameters)
importFrom(insight,get_predictors)
importFrom(insight,get_random)
importFrom(insight,get_response)
importFrom(insight,get_variance)
importFrom(insight,get_weights)
importFrom(insight,model_info)
importFrom(parameters,model_parameters)
importFrom(parameters,parameters_type)
importFrom(performance,check_heterogeneity_bias)
importFrom(stats,anova)
importFrom(stats,aov)
importFrom(stats,as.formula)
importFrom(stats,ave)
importFrom(stats,chisq.test)
importFrom(stats,complete.cases)
importFrom(stats,contrasts)
importFrom(stats,delete.response)
importFrom(stats,kruskal.test)
importFrom(stats,lm)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,na.omit)
importFrom(stats,optim)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,plogis)
importFrom(stats,pnorm)
importFrom(stats,prop.test)
importFrom(stats,pt)
importFrom(stats,qchisq)
importFrom(stats,qf)
importFrom(stats,qlogis)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,reshape)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,var)
importFrom(stats,weighted.mean)
importFrom(utils,as.roman)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,tail)
