#' @importFrom bayestestR equivalence_test
#' @export
bayestestR::equivalence_test

#' @export
#' @importFrom datawizard standardize
datawizard::standardize





## TODO: removed the following from see / modelbased --------------------

#' @export
#' @importFrom datawizard ranktransform
datawizard::ranktransform

#' @export
#' @importFrom datawizard adjust
datawizard::adjust

#' @export
#' @importFrom datawizard change_scale
datawizard::change_scale

#' @export
#' @importFrom datawizard normalize
datawizard::normalize

#' @export
#' @importFrom datawizard unstandardize
datawizard::unstandardize