#' @importFrom bayestestR equivalence_test
#' @export
bayestestR::equivalence_test

#' @export
#' @importFrom datawizard standardize
datawizard::standardize

#' @export
#' @importFrom datawizard standardise
datawizard::standardise

#' @export
#' @importFrom parameters standardize_parameters
parameters::standardize_parameters

#' @export
#' @importFrom parameters standardize_posteriors
parameters::standardize_posteriors


#' @export
#' @importFrom parameters standardize_info
parameters::standardize_info



# Printing ----------------------------------------------------------------

#' @export
#' @importFrom insight display
insight::display

#' @export
#' @importFrom insight print_html
insight::print_html

#' @export
#' @importFrom insight print_md
insight::print_md
